# mailslurp-client
For documentation see [developer guide](https://www.mailslurp.com/developers). [Create an account](https://app.mailslurp.com) in the MailSlurp Dashboard to [view your API Key](https://app). For all bugs, feature requests, or help please [see support](https://www.mailslurp.com/support/).

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.0.1-alpha
- Package version: 4.1.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://www.mailslurp.com](https://www.mailslurp.com)

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import mailslurp_client 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import mailslurp_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import mailslurp_client
from mailslurp_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: API_KEY
configuration = mailslurp_client.Configuration()
configuration.api_key['x-api-key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['x-api-key'] = 'Bearer'

# create an instance of the API class
api_instance = mailslurp_client.CommonOperationsApi(mailslurp_client.ApiClient(configuration))

try:
    # Create new email address
    api_response = api_instance.create_new_email_address_using_post()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling CommonOperationsApi->create_new_email_address_using_post: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.mailslurp.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CommonOperationsApi* | [**create_new_email_address_using_post**](docs/CommonOperationsApi.md#create_new_email_address_using_post) | **POST** /newEmailAddress | Create new email address
*CommonOperationsApi* | [**fetch_latest_email_using_get**](docs/CommonOperationsApi.md#fetch_latest_email_using_get) | **GET** /fetchLatestEmail | Fetch inbox&#39;s latest email or if empty wait for email to arrive
*CommonOperationsApi* | [**send_email_simple_using_post**](docs/CommonOperationsApi.md#send_email_simple_using_post) | **POST** /sendEmail | Send an email from a random email address
*ExtraOperationsApi* | [**bulk_create_inboxes_using_post**](docs/ExtraOperationsApi.md#bulk_create_inboxes_using_post) | **POST** /bulk/inboxes | Bulk create Inboxes (email addresses)
*ExtraOperationsApi* | [**bulk_delete_inboxes_using_delete**](docs/ExtraOperationsApi.md#bulk_delete_inboxes_using_delete) | **DELETE** /bulk/inboxes | Bulk Delete Inboxes
*ExtraOperationsApi* | [**bulk_send_emails_using_post**](docs/ExtraOperationsApi.md#bulk_send_emails_using_post) | **POST** /bulk/send | Bulk Send Emails
*ExtraOperationsApi* | [**create_inbox_using_post**](docs/ExtraOperationsApi.md#create_inbox_using_post) | **POST** /inboxes | Create an Inbox (email address)
*ExtraOperationsApi* | [**create_inbox_webhook_using_post**](docs/ExtraOperationsApi.md#create_inbox_webhook_using_post) | **POST** /inboxes/{inboxId}/webhooks | Attach a webhook URL to an inbox
*ExtraOperationsApi* | [**delete_email_using_delete**](docs/ExtraOperationsApi.md#delete_email_using_delete) | **DELETE** /emails/{emailId} | Delete Email
*ExtraOperationsApi* | [**delete_inbox_using_delete**](docs/ExtraOperationsApi.md#delete_inbox_using_delete) | **DELETE** /inboxes/{inboxId} | Delete Inbox
*ExtraOperationsApi* | [**get_email_attachment_using_get**](docs/ExtraOperationsApi.md#get_email_attachment_using_get) | **GET** /emails/{emailId}/attachments/{attachmentId} | Get email attachment
*ExtraOperationsApi* | [**get_email_using_get**](docs/ExtraOperationsApi.md#get_email_using_get) | **GET** /emails/{emailId} | Get Email Content
*ExtraOperationsApi* | [**get_emails_using_get**](docs/ExtraOperationsApi.md#get_emails_using_get) | **GET** /inboxes/{inboxId}/emails | List an Inbox&#39;s Emails
*ExtraOperationsApi* | [**get_inbox_using_get**](docs/ExtraOperationsApi.md#get_inbox_using_get) | **GET** /inboxes/{inboxId} | Get Inbox
*ExtraOperationsApi* | [**get_inbox_webhooks_using_delete**](docs/ExtraOperationsApi.md#get_inbox_webhooks_using_delete) | **DELETE** /inboxes/{inboxId}/webhooks/{webhookId} | Delete and disable a webhook for an inbox
*ExtraOperationsApi* | [**get_inbox_webhooks_using_get**](docs/ExtraOperationsApi.md#get_inbox_webhooks_using_get) | **GET** /inboxes/{inboxId}/webhooks | Get all webhooks for an inbox
*ExtraOperationsApi* | [**get_inboxes_using_get**](docs/ExtraOperationsApi.md#get_inboxes_using_get) | **GET** /inboxes | List Inboxes
*ExtraOperationsApi* | [**get_raw_email_using_get**](docs/ExtraOperationsApi.md#get_raw_email_using_get) | **GET** /emails/{emailId}/raw | Get Raw Email Content
*ExtraOperationsApi* | [**send_email_using_post**](docs/ExtraOperationsApi.md#send_email_using_post) | **POST** /inboxes/{inboxId} | Send Email


## Documentation For Models

 - [BasicAuthOptions](docs/BasicAuthOptions.md)
 - [BulkSendEmailOptions](docs/BulkSendEmailOptions.md)
 - [CreateWebhookOptions](docs/CreateWebhookOptions.md)
 - [Email](docs/Email.md)
 - [EmailAnalysis](docs/EmailAnalysis.md)
 - [EmailPreview](docs/EmailPreview.md)
 - [Inbox](docs/Inbox.md)
 - [SendEmailOptions](docs/SendEmailOptions.md)
 - [Webhook](docs/Webhook.md)


## Documentation For Authorization


## API_KEY

- **Type**: API key
- **API key parameter name**: x-api-key
- **Location**: HTTP header


## Author

contact@mailslurp.dev


